@@ -50,7 +50,7 @@ namespace {
 /////////////
 const int LEFT_MARGIN = 10;
 const QSize ICON_SIZE = QSize(50, 50);
-const int ICON_SPACING = 10;
+const int ICON_SPACING = 9;
 const int FILENAME_MAX_LENGTH = 600;
 const int RIGHT_TITLEBAR_WIDTH = 100;
 const QString LOCMAP_SELECTED_DARK = ":/dark/images/58 drak.svg";
@@ -70,7 +70,7 @@ const int THUMBNAIL_WIDTH = 32;
 const int THUMBNAIL_ADD_WIDTH = 32;
 const int THUMBNAIL_LIST_ADJUST = 9;
 const int THUMBNAIL_VIEW_DVALUE = 668;
-
+const int MAINWINDOW_MIN_WIDTH = 630;
 const int LOAD_LEFT_RIGHT = 25;     //前后加载图片数（动态）
 
 }  // namespace
@@ -543,6 +543,18 @@ void LibBottomToolbar::onThumbnailChanged(QPixmap pix, const QSize &originalSize
 void LibBottomToolbar::resizeEvent(QResizeEvent *event)
 {
     Q_UNUSED(event);
+
+    if (LibCommonService::instance()->getImgViewerType() == imageViewerSpace::ImgViewerType::ImgViewerTypeAlbum
+            && m_imgListWidget->isVisible()) {
+        if ((topLevelWidget()->width() - MAINWINDOW_MIN_WIDTH) < (ICON_SIZE.width() * 2)) {
+            m_rotateRBtn->setVisible(false);
+            m_rotateLBtn->setVisible(false);
+        } else {
+            m_rotateRBtn->setVisible(true);
+            m_rotateLBtn->setVisible(true);
+        }
+    }
+
     emit sigResizeBottom();
     m_imgListWidget->moveCenterWidget();
 }
@@ -550,6 +562,18 @@ void LibBottomToolbar::resizeEvent(QResizeEvent *event)
 void LibBottomToolbar::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event);
+
+    if (LibCommonService::instance()->getImgViewerType() == imageViewerSpace::ImgViewerType::ImgViewerTypeAlbum
+            && m_imgListWidget->isVisible()) {
+        if ((topLevelWidget()->width() - MAINWINDOW_MIN_WIDTH) < (ICON_SIZE.width() * 2)) {
+            m_rotateRBtn->setVisible(false);
+            m_rotateLBtn->setVisible(false);
+        } else {
+            m_rotateRBtn->setVisible(true);
+            m_rotateLBtn->setVisible(true);
+        }
+    }
+
     m_imgListWidget->moveCenterWidget();
 }
 
@@ -733,7 +757,7 @@ void LibBottomToolbar::initUI()
 
     //增加缩略图左侧空隙
     m_spaceWidget_thumbnailLeft = new QWidget(this);
-    m_spaceWidget_thumbnailLeft->setFixedWidth(1);
+    m_spaceWidget_thumbnailLeft->setFixedWidth(0);
     hb->addWidget(m_spaceWidget_thumbnailLeft);
 
     //缩略图列表
