@@ -55,7 +55,6 @@
 #include <DGuiApplicationHelper>
 #include <DApplicationHelper>
 
-
 #ifndef QT_NO_OPENGL
 //#include <QGLWidget>
 #endif
@@ -476,7 +475,8 @@ void LibImageGraphicsView::setImage(const QString &path, const QImage &image)
                 m_morePicFloatWidget->setVisible(false);
             }
             m_morePicFloatWidget->setLabelText(QString::number(m_imageReader->currentImageNumber() + 1) + "/" + QString::number(m_imageReader->imageCount()));
-            m_morePicFloatWidget->move(this->width() - 80, this->height() / 2 - 50);
+            //由于最小化窗口尺寸过小，会遮盖掉切换栏，抬高30px
+            m_morePicFloatWidget->move(this->width() - 80, this->height() / 2 -80);
         }
     }
     m_firstset = true;
@@ -567,6 +567,7 @@ const QImage LibImageGraphicsView::image()
 void LibImageGraphicsView::fitWindow()
 {
     qreal wrs = windowRelativeScale();
+    qDebug()<<wrs;
     resetTransform();
     //可能存在比例超过20.0的情况，设置为20.0
     if (wrs > 20.0) {
@@ -650,6 +651,10 @@ qreal LibImageGraphicsView::imageRelativeScale() const
 qreal LibImageGraphicsView::windowRelativeScale() const
 {
     QRectF bf = sceneRect();
+    qDebug()<<bf.width();
+    qDebug()<<bf.height();
+    qDebug()<<width();
+    qDebug()<<height();
     //新需求,默认适应窗口顶格到标题栏
     if (1.0 * width() / (height() - TITLEBAR_HEIGHT * 2) > 1.0 * bf.width() / (bf.height())) {
 //    if (1.0 * width() / (height() - TITLEBAR_HEIGHT * 2) > 1.0 * bf.width() / (bf.height() - TITLEBAR_HEIGHT * 2)) {
@@ -908,7 +913,27 @@ bool LibImageGraphicsView::slotRotatePixmap(int nAngel)
     autoFit();
     m_rotateAngel += nAngel;
 
-    emit currentThumbnailChanged(pixmap, pixmap.size());
+    QPixmap thumbnailPixmap;
+    if (0 != pixmap.height() && 0 != pixmap.width() && (pixmap.height() / pixmap.width()) < 10 && (pixmap.width() / pixmap.height()) < 10) {
+        bool cache_exist = false;
+        if (pixmap.height() != 200 && pixmap.width() != 200) {
+            if (pixmap.height() >= pixmap.width()) {
+                cache_exist = true;
+                thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+            } else if (pixmap.height() <= pixmap.width()) {
+                cache_exist = true;
+                thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+            }
+        }
+        if (!cache_exist) {
+            if (static_cast<float>(pixmap.height()) / static_cast<float>(pixmap.width()) > 3) {
+                thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+            } else {
+                thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+            }
+        }
+    }
+    emit currentThumbnailChanged(thumbnailPixmap, pixmap.size());
     emit imageChanged(m_path);
     return true;
 }
@@ -1033,7 +1058,8 @@ void LibImageGraphicsView::resizeEvent(QResizeEvent *event)
     qDebug() << "---" << __FUNCTION__ << "---" << event->size();
     //20201027曾在右侧浮动窗口，关于多图片
     if (m_morePicFloatWidget) {
-        m_morePicFloatWidget->move(this->width() - 80, this->height() / 2 - 50);
+        //由于最小化窗口尺寸过小，会遮盖掉切换栏，抬高30px
+        m_morePicFloatWidget->move(this->width() - 80, this->height() / 2 - 80);
     }
     titleBarControl();
     if (!m_isFitWindow) {
@@ -1147,7 +1173,6 @@ void LibImageGraphicsView::onCacheFinish()
             if (!m_pixmapItem) {
                 return;
             }
-
             QPixmap pixmap = vl.last().value<QPixmap>();
             QPixmap tmpPixmap = pixmap;
             tmpPixmap.setDevicePixelRatio(devicePixelRatioF());
@@ -1160,7 +1185,6 @@ void LibImageGraphicsView::onCacheFinish()
                 pixmap = pixmap.transformed(rotate, Qt::SmoothTransformation);
                 m_newImageRotateAngle = 0;
             }
-
             m_pixmapItem->setGraphicsEffect(nullptr);
             m_pixmapItem->setPixmap(pixmap);
             setSceneRect(m_pixmapItem->boundingRect());
@@ -1168,10 +1192,32 @@ void LibImageGraphicsView::onCacheFinish()
             emit imageChanged(path);
             this->update();
             m_newImageLoadPhase = FullFinish;
-
             //刷新缩略图
             if (!pixmap.isNull()) {
-                emit currentThumbnailChanged(pixmap, pixmap.size());
+                QPixmap thumbnailPixmap;
+                if (0 != pixmap.height() && 0 != pixmap.width() && (pixmap.height() / pixmap.width()) < 10 && (pixmap.width() / pixmap.height()) < 10) {
+                    bool cache_exist = false;
+                    if (pixmap.height() != 200 && pixmap.width() != 200) {
+                        if (pixmap.height() >= pixmap.width()) {
+                            cache_exist = true;
+                            thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+                        } else if (pixmap.height() <= pixmap.width()) {
+                            cache_exist = true;
+                            thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+                        }
+                    }
+                    if (!cache_exist) {
+                        if (static_cast<float>(pixmap.height()) / static_cast<float>(pixmap.width()) > 3) {
+                            thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+                        } else {
+                            thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+                        }
+                    }
+                }
+                else {
+                    thumbnailPixmap = pixmap.scaled(200,200);
+                }
+                emit currentThumbnailChanged(thumbnailPixmap, pixmap.size());
             }
 
         }
@@ -1320,6 +1366,7 @@ void LibImageGraphicsView::pinchTriggered(QPinchGesture *gesture)
 
 void LibImageGraphicsView::OnFinishPinchAnimal()
 {
+
     m_rotateflag = true;
     m_bnextflag = true;
     m_rotateAngelTouch = 0;
@@ -1356,7 +1403,27 @@ void LibImageGraphicsView::OnFinishPinchAnimal()
         m_rotateAngel += m_endvalue;
         if (m_endvalue > 0) {
             emit gestureRotate(static_cast<int>(0));
-            emit currentThumbnailChanged(pixmap, pixmap.size());
+            QPixmap thumbnailPixmap;
+            if (0 != pixmap.height() && 0 != pixmap.width() && (pixmap.height() / pixmap.width()) < 10 && (pixmap.width() / pixmap.height()) < 10) {
+                bool cache_exist = false;
+                if (pixmap.height() != 200 && pixmap.width() != 200) {
+                    if (pixmap.height() >= pixmap.width()) {
+                        cache_exist = true;
+                        thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+                    } else if (pixmap.height() <= pixmap.width()) {
+                        cache_exist = true;
+                        thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+                    }
+                }
+                if (!cache_exist) {
+                    if (static_cast<float>(pixmap.height()) / static_cast<float>(pixmap.width()) > 3) {
+                        thumbnailPixmap = pixmap.scaledToWidth(200,  Qt::FastTransformation);
+                    } else {
+                        thumbnailPixmap = pixmap.scaledToHeight(200,  Qt::FastTransformation);
+                    }
+                }
+            }
+            emit currentThumbnailChanged(thumbnailPixmap, pixmap.size());
             emit UpdateNavImg();
         }
     }
