@@ -52,6 +52,7 @@
 #include "service/ocrinterface.h"
 #include "slideshow/slideshowpanel.h"
 #include "service/configsetter.h"
+#include "service/imagedataservice.h"
 
 const QString IMAGE_TMPPATH =   QDir::homePath() +
                                 "/.config/deepin/deepin-image-viewer/";
@@ -110,8 +111,28 @@ LibViewPanel::LibViewPanel(AbstractTopToolbar *customToolbar, QWidget *parent)
     setAcceptDrops(true);
 //    initExtensionPanel();
 
-    QObject::connect(m_view, &LibImageGraphicsView::currentThumbnailChanged, m_bottomToolbar, &LibBottomToolbar::onThumbnailChanged);
+    QObject::connect(m_view, &LibImageGraphicsView::currentThumbnailChanged, m_bottomToolbar, &LibBottomToolbar::onThumbnailChanged, Qt::DirectConnection);
     QObject::connect(m_view, &LibImageGraphicsView::gestureRotate, this, &LibViewPanel::slotRotateImage);
+
+    //删除完了图片需要返回原状bug137195
+    QObject::connect(ImageEngine::instance(), &ImageEngine::sigPicCountIsNull, this, [ = ] {
+        if (ImgViewerType::ImgViewerTypeAlbum != LibCommonService::instance()->getImgViewerType())
+        {
+            if (window()->isFullScreen()) {
+                window()->showNormal();
+                window()->resize(m_windowSize);
+                window()->move(m_windowX, m_windowY);
+                QTimer::singleShot(50, [ = ] {
+                    window()->move(m_windowX, m_windowY);
+                });
+            }
+        }
+    });
+
+    // 添加过滤处理，当窗口出现状态变更时(最大化、全屏)，处理标题栏隐藏、显示
+    if (window()) {
+        window()->installEventFilter(this);
+    }
 }
 
 LibViewPanel::~LibViewPanel()
@@ -632,6 +653,10 @@ void LibViewPanel::toggleFullScreen()
 
 void LibViewPanel::showFullScreen()
 {
+    m_windowSize = window()->size();
+    m_windowX = window()->x();
+    m_windowY = window()->y();
+
     if (m_view) {
         m_view->setWindowIsFullScreen(true);
     }
@@ -1594,8 +1619,9 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
 
             PrintHelper::getIntance()->showPrintDialog(QStringList(m_bottomToolbar->getCurrentItemInfo().path), this);
 
-            //开启定时器
-            m_hideCursorTid = startTimer(DELAY_HIDE_CURSOR_INTERVAL);
+            // 全屏时，开启定时器，3秒后隐藏鼠标
+            if (window()->isFullScreen())
+                m_hideCursorTid = startTimer(DELAY_HIDE_CURSOR_INTERVAL);
             break;
         }
         case IdRename: {
@@ -2025,7 +2051,8 @@ void LibViewPanel::dropEvent(QDropEvent *event)
 void LibViewPanel::timerEvent(QTimerEvent *e)
 {
     if (e->timerId() == m_hideCursorTid && (!m_menu || !m_menu->isVisible())) {
-        m_view->viewport()->setCursor(Qt::BlankCursor);
+        if (!QApplication::activeModalWidget())
+            m_view->viewport()->setCursor(Qt::BlankCursor);
     }
 
     QFrame::timerEvent(e);
@@ -2047,5 +2074,27 @@ void LibViewPanel::hideEvent(QHideEvent *e)
         m_extensionPanel->setVisible(false);
     }
 
+    LibImageDataService::instance()->stopReadThumbnail();
+
     QFrame::hideEvent(e);
 }
+
+bool LibViewPanel::eventFilter(QObject *o, QEvent *e)
+{
+    // 判断是否为窗口的状态变化
+    if (window() == o
+            && QEvent::WindowStateChange == e->type()) {
+        if (m_topToolbar) {
+            if (window()->isFullScreen()) {
+                // 全屏状态下隐藏标题栏
+                m_topToolbar->setVisible(false);
+            } else {
+                if (!m_topToolBarIsAlwaysHide) {
+                    m_topToolbar->setVisible(true);
+                }
+            }
+        }
+    }
+
+    return QFrame::eventFilter(o, e);
+}
