@@ -207,6 +207,10 @@ protected:
     void leaveEvent(QEvent *event) override;
 
     void hideEvent(QHideEvent *e) override;
+
+    // 捕获窗口的状态变更事件
+    bool eventFilter(QObject *o, QEvent *e) override;
+
 signals:
     void imageChanged(const QString &path);
 
@@ -261,5 +265,9 @@ private:
     QFileSystemWatcher *m_dirWatcher = nullptr;
 
     bool m_isShowTopBottom = true;
+
+    QSize m_windowSize;
+    int m_windowX = 0;
+    int m_windowY = 0;
 };
 #endif  // VIEWPANEL_H
